dump_all

Function dump_all 

pub fn dump_all<'a, 'id, FR: Deref, D>(
    file: impl Write,
    manager: &<FR::Target as Function>::Manager<'id>,
    functions: impl IntoIterator<Item = (FR, D)>,
) -> Result<()>
where FR::Target: 'a + Function + DotStyle<ETagOfFunc<'id, FR::Target>>, ETagOfFunc<'id, FR::Target>: Debug, TermOfFunc<'id, FR::Target>: Display, D: Display,
Dump the entire decision diagram represented by manager as Graphviz DOT code to file

To label functions in the decision diagram, you can pass pairs of function and name (type D, implementing std::fmt::Display).