pub trait DotStyle<T: Tag> {
// Provided method
fn edge_style(no: usize, tag: T) -> (EdgeStyle, bool, Color) { ... }
}Expand description
Styling attributes defined by the node type
Provided Methods
Sourcefn edge_style(no: usize, tag: T) -> (EdgeStyle, bool, Color)
fn edge_style(no: usize, tag: T) -> (EdgeStyle, bool, Color)
Get the style for the n-th outgoing edge, tagged with tag
Returns the edge style (solid/dashed/dotted), whether it is bold, and the color.
The default implementation distinguishes three kinds of edges (all non-bold and black):
- If the edge is tagged (i.e.
tagis not the default value) then the edge is dotted. - If the edge is untagged and the second edge (
no == 1), then it is dashed - Otherwise the edge is solid
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".