Struct oxidd_dump::dddmp::DumpHeader
source · pub struct DumpHeader { /* private fields */ }Expand description
Information from the header of a DDDMP file
Implementations
sourceimpl DumpHeader
impl DumpHeader
sourcepub fn load(input: impl BufRead) -> Result<Self>
pub fn load(input: impl BufRead) -> Result<Self>
Load the DDDMP header of the given input
This always needs to be called before import() to retrieve some
necessary information and to position the input’s cursor.
sourcepub fn diagram_name(&self) -> Option<&str>
pub fn diagram_name(&self) -> Option<&str>
Name of the decision diagram
Corresponds to the DDDMP .dd field.
sourcepub fn num_nodes(&self) -> usize
pub fn num_nodes(&self) -> usize
Number of nodes in the dumped decision diagram
Corresponds to the DDDMP .nnodes field.
sourcepub fn num_vars(&self) -> u32
pub fn num_vars(&self) -> u32
Number of all variables in the exported decision diagram
Corresponds to the DDDMP .nvars field.
sourcepub fn num_support_vars(&self) -> u32
pub fn num_support_vars(&self) -> u32
Number of variables in the true support of the decision diagram
Corresponds to the DDDMP .nsuppvars field.
sourcepub fn support_vars(&self) -> &[u32]
pub fn support_vars(&self) -> &[u32]
Variables in the true support of the decision diagram. Concretely, these
are indices of the original variable numbering. Hence, the returned
slice contains DumpHeader::num_support_vars() integers in strictly
ascending order.
Example: Consider a decision diagram that was created with the variables
x, y and z, in this order (x is the top-most variable). Suppose
that only y and z are used by the dumped functions. Then this
function returns [1, 2] regardless of any subsequent reordering.
Corresponds to the DDDMP .ids field.
sourcepub fn support_var_permutation(&self) -> &[u32]
pub fn support_var_permutation(&self) -> &[u32]
Permutation of the variables in the true support of the decision
diagram. The returned slice is always DumpHeader::num_support_vars()
elements long. If the value at the ith index is l, then the ith
support variable is at level l in the dumped decision diagram. By the
ith support variable, we mean the variable header.support_vars()[i]
in the original numbering.
Example: Consider a decision diagram that was created with the variables
x, y and z (x is the top-most variable). The variables were
re-ordered to z, x, y. Suppose that only y and z are used by
the dumped functions. Then this function returns [2, 0].
Corresponds to the DDDMP .permids field.
sourcepub fn auxiliary_var_ids(&self) -> &[u32]
pub fn auxiliary_var_ids(&self) -> &[u32]
Auxiliary variable IDs. The returned slice contains
DumpHeader::num_support_vars() elements.
Corresponds to the DDDMP .auxids field.
sourcepub fn support_var_names(&self) -> Option<&[String]>
pub fn support_var_names(&self) -> Option<&[String]>
Names of variables in the true support of the decision diagram. If
present, the returned slice contains DumpHeader::num_support_vars()
many elements. The order is the “original” variable order.
Example: Consider a decision diagram that was created with the variables
x, y and z, in this order (x is the top-most variable). Suppose
that only y and z are used by the dumped functions. Then this
function returns ["y", "z"] regardless of any subsequent reordering.
Corresponds to the DDDMP .suppvarnames field.
sourcepub fn ordered_var_names(&self) -> Option<&[String]>
pub fn ordered_var_names(&self) -> Option<&[String]>
Names of all variables in the exported decision diagram. If present, the
returned slice contains DumpHeader::num_vars() many elements. The
order is the “current” variable order, i.e. the first name corresponds
to the top-most variable in the dumped decision diagram.
Example: Consider a decision diagram that was created with the variables
x, y and z (x is the top-most variable). The variables were
re-ordered to z, x, y. In this case, the function returns
["z", "x", "y"] (even if some of the variables are unused by the
dumped functions).
Corresponds to the DDDMP .nvars field.
sourcepub fn num_roots(&self) -> usize
pub fn num_roots(&self) -> usize
Number of roots
import() returns this number of roots on success.
Corresponds to the DDDMP .nroots field.
sourcepub fn root_names(&self) -> Option<&[String]>
pub fn root_names(&self) -> Option<&[String]>
Names of roots, if present, in the same order as returned by
import()
Corresponds to the DDDMP .rootnames field.